# python_jenkins_moniotr
可模拟jenkins的时间定时设置，返回下一次执行的时间戳
---------
## 功能：  
  根据调用时间和定时设置字符串，返回定时任务的下一次执行时间的时间戳(前10位整数部分)，精确到分，。当之后不会再有执行时间，则返回None
## 原理：  
  - 定时设置字符串：'* * * * *' 
  - 分别代表分、时、日、月、星期 
  - 星号* 代表所有，仅在分/时/日/月标记内，不考虑闰年
  - 横线- 代表区间，如1-5 代表：1，2，3，4，5
  - 斜杠/ 代表间隔，如1-5/2 代表：1，3，5
  - 逗号, 代表多种取值，如 1,4,7 代表：1，4，,7
## 优点：
  - 可完全模拟jenkins的定时任务设置，用在各种自定义的定时任务平台或脚本中
## 注意：
  - 尽量不要使用 * * * * * ,此时计算方式为避免大量计算，所以会改为自动返回当前时间的下一分钟，并且一分钟执行一次。
## 第三方依赖包:  
  暂无
